#
# spec file for package libdbusmenu-qt5
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define rname libdbusmenu-qt

Name:           libdbusmenu-qt5
Version:        0.9.3+15.10.20150604
Release:        4.41
Url:            https://launchpad.net/libdbusmenu-qt/
Summary:        A Qt implementation of the DBusMenu protocol
License:        LGPL-2.0+
Group:          System/Libraries
Source:         http://archive.ubuntu.com/ubuntu/pool/main/libd/%{rname}/%{rname}_%{version}.orig.tar.gz
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM noqDebug-qWarnings.patch -- libdbusmenu uses it's own qDebug's and qWarnings,
# which are useless, and annoy users, so this patch just disables them in release mode
Patch1:         noqDebug-qWarnings.patch
# PATCH-FIX-UPSTREAM full_include_dir.patch -- CMake 2.8.12 creates a fatal error on relative include dirs for a target. silence that policy
Patch2:         full_include_dir.patch
#Needed for DISABLE_FIND_PACKAGE
BuildRequires:  cmake >= 2.8.6
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This library provides a Qt implementation of the DBusMenu protocol.

The DBusMenu protocol makes it possible for applications to export and import
their menus over DBus. Qt5 library

%package -n libdbusmenu-qt5-2
Summary:        Development package for dbusmenu-qt5
Group:          System/Libraries

%description -n libdbusmenu-qt5-2
This library provides a Qt implementation of the DBusMenu protocol.

The DBusMenu protocol makes it possible for applications to export and import
their menus over DBus. Qt5 library

%package -n libdbusmenu-qt5-devel
Summary:        Development package for libdbusmenu-qt5
Group:          Development/Libraries/Other
Requires:       libdbusmenu-qt5-2 = %{version}
Requires:       pkgconfig(Qt5Core)

%description -n libdbusmenu-qt5-devel
This package contains development files for libdbusmenu-qt5.

%prep
%setup -q -n %{rname}-%{version}
%patch1 -p1
%if 0%{?suse_version} <= 1310
%patch2 -p1
%endif

# Remove build time references so build-compare can do its work
sed -i "s/HTML_TIMESTAMP         = YES/HTML_TIMESTAMP         = NO/" Doxyfile.in

%build
mkdir build
pushd build
export CFLAGS="%{optflags} -DQT_NO_DEBUG -DQT_NO_DEBUG_OUTPUT -DQT_NO_WARNING_OUTPUT"
export CXXFLAGS="%{optflags} -DQT_NO_DEBUG -DQT_NO_DEBUG_OUTPUT -DQT_NO_WARNING_OUTPUT"
export LDFLAGS="-Wl,-Bsymbolic-functions $LDFLAGS"
_libsuffix=$(echo %{_lib} | cut -b4-)
cmake -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} \
      -DLIB_SUFFIX="$_libsuffix" \
      -DUSE_QT5=ON \
      -DCMAKE_DISABLE_FIND_PACKAGE_QJSON=TRUE \
      -DCMAKE_BUILD_TYPE=release ..
make %{?_smp_mflags} VERBOSE=1
popd

%install
%makeinstall -C build

# Install the documentation in the correct location
mkdir -p %{buildroot}%{_docdir}/libdbusmenu-qt5-devel
mv %{buildroot}%{_datadir}/doc/libdbusmenu-qt5-doc/ %{buildroot}%{_docdir}/libdbusmenu-qt5-devel/html/
# Install additional documentation
install -pm 0644 COPYING NEWS README %{buildroot}%{_docdir}/libdbusmenu-qt5-devel/

%fdupes -s %{buildroot}%{_docdir}/libdbusmenu-qt5-devel/

%post -n libdbusmenu-qt5-2 -p /sbin/ldconfig

%postun -n libdbusmenu-qt5-2 -p /sbin/ldconfig

%files -n libdbusmenu-qt5-2
%defattr(-,root,root,-)
%{_libdir}/libdbusmenu-qt5.so.2*

%files -n libdbusmenu-qt5-devel
%defattr(-,root,root,-)
%doc %{_docdir}/libdbusmenu-qt5-devel/
%{_libdir}/libdbusmenu-qt5.so
%{_includedir}/dbusmenu-qt5/
%{_libdir}/pkgconfig/dbusmenu-qt5.pc
%{_libdir}/cmake/dbusmenu-qt5/

%changelog
* Thu Jun 25 2015 hrvoje.senjan@gmail.com
- Update to 0.9.3+15.10.20150604:
  * Fixed memory leaks
- Drop Clean-up-variable-naming.patch and dont-leak-all-the-watchers.diff,
  merged upstream
* Fri May 15 2015 hrvoje.senjan@gmail.com
- Replace avoid-shadowing-variable+fix-leak.diff with Clean-up-variable-naming.patch
* Mon May 11 2015 hrvoje.senjan@gmail.com
- Add patches from upstream:
  dont-leak-all-the-watchers.diff and
  avoid-shadowing-variable+fix-leak.diff
* Mon Sep 15 2014 hrvoje.senjan@gmail.com
- Update to 0.9.3+14.10.20140619
  * Users of dbusmenu-qt no longer need to call
    include_directories(${dbusmenu-qt5_INCLUDE_DIRS}).
    Simply adding dbusmenu-qt5 to the target_link_libraries()
    call takes care of defining the include directory.
- Rebase noqDebug-qWarnings.patch
- Added full_include_dir.patch for openSUSE 13.1
* Mon Jun  2 2014 hrvoje.senjan@gmail.com
- Improve baselibs.conf
* Thu Feb  6 2014 hrvoje.senjan@gmail.com
- Be more explicit about needed BuildRequires (added pkgconfig(Qt5DBus)
  and pkgconfig(Qt5Widgets) -- fixes build with latest Qt5 packaging
  changes)
* Wed Dec 18 2013 hrvoje.senjan@gmail.com
- Update to 0.9.2+14.04.20131209
  * Install CMake config files for dbusmenu-qt and dbusmenu-qt5.
    This makes it easy for other projects to use the library with
    find(dbusmenu-qt) or find(dbusmenu-qt5) without having to ship
    a FindDBusMenuQt.cmake file. (More about this topic here:
    http://www.cmake.org/Wiki/CMake/Tutorials/Packaging ). Test
    programs available here:
    http://agateau.com/tmp/dmqt-samples.tar.bz2.
  * Destructors of classes intended to be base classes updated to
    virtual.
  * When adding a new submenu action, refresh() that action to
    ensure full menu hierarchy is built.
- Rebase noqDebug-qWarnings.patch to this release
* Wed Nov  6 2013 hrvoje.senjan@gmail.com
- Update to 0.9.2+13.10.20130826
  * Various bugfixes
  * Qt5 port
- Build Qt5 library
- Droped 237_236.diff, merged upstream
* Sun Aug 25 2013 hrvoje.senjan@gmail.com
- Added 237_236.diff from upstream, fixes lp#1068050 (Some icons of
  kate menu are wrong when run with the global menubar) and
  noqDebug-qWarnings.patch, which disables spamming users with
  useless debug
* Wed Apr 11 2012 asterios.dramis@gmail.com
- Update to 0.9.2:
  * Fix disabling and hiding actions
  * Avoid spamming dbus at startup
  * Do not print warnings when not necessary
  From 0.9.1:
  * Add support for "opened" and "closed" events
  * Add support for icon-data (LP BUG 633339)
- Install also the development documentation.
* Thu Sep  1 2011 asterios.dramis@gmail.com
- Update to 0.9.0:
  * Add support for the "Status" dbusmenu property. Will be used by appmenu-qt
    for LP BUG 737419
  - Collapse multiple separators, get rid of starting and trailing separators
    (LP BUG 793339) (Aurelien Gateau)
- Spec file updates:
  * Changed License: to LGPL-2.0+.
  * Minor other updates.
* Sat Jun 25 2011 asterios.dramis@gmail.com
- Update to 0.8.3:
  * If DBusMenuExporter is deleted, delete all DBusMenu instances which were
    working with it
  * Only show icons in menu if the platform allows them
* Sun May 15 2011 asterios.dramis@gmail.com
- Update to 0.8.2:
  * Shortcut handling: Translate "+" into "plus" and "-" into "minus" (LP BUG
    712565)
  From 0.8.1:
  * Added target to build documentation with Doxygen
  From 0.8.0:
  * Implements version 2 of the dbusmenu protocol
  * Merged support for KMenu titles
  From 0.7.0:
  * Switched DBus domain from org.ayatana to com.canonical
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed License: to LGPLv2+.
  * Removed dbus-1-devel from BuildRequires:.
  * Added doxygen and libqjson-devel in BuildRequires:.
  * Updates in Summary, %%description and Group entries.
  * Removed /sbin/ldconfig from devel package %%post* scripts (not needed).
  * Minor other updates.
* Wed Dec 22 2010 rwooninck@opensuse.org
- update to 0.6.6
  * Avoid false warnings
  * Make sure we don't track actions twice (bko254066)
  * CMake-parser-friendly of dbusmenu_version.h
  * Trigger action asynchronously when the "clicked" event is
    received (LP bug 643393)
  * Fixed copyright headers
  * Removed all code which did not belong to Canonical.
  * Fix some memory leaks
  * Do not keep dangling pointers to deleted actions (LP bug 624964)
  * Added the DBusMenuImporter::actionActivationRequested(QAction*)
    signal
  * Fix hardcoded libdir in pkgconfig file (LP BUG 610633)
* Tue Sep 14 2010 dmueller@suse.de
- fix runtime dependencies
* Fri Aug 13 2010 tittiatcoke@gmail.com
- update to 0.5.2
  * Fix implementation of GetGroupProperties()
  * Fix detection of QIcon::name() with gold
  * Add support for KMenu titles
  * Queue calls to refresh() because we may be spammed with many
    LayoutUpdated() signals at once
  * Turned DBusMenuImporter::updateMenu() into a slot
  * Introduce a dbusmenu_version.h file
  * Introduce updateMenu() and menuUpdated(), deprecate
    menuReadyToBeShown()
  * Better build check for QIcon::name() (LP BUG 597975)
  * Rework the way menuReadyToBeShown() is emitted
  * Queue LayoutUpdated() signal to avoid emitting it too often
  * Increase timeouts: prefer slow but complete menus to fast
    but incomplete
  * Use QIcon::name() to return the icon name, when built
    with Qt 4.7
  * Correctly handle non-exclusive action groups
  * bugfix (bko#237156)
  * Added support for shortcuts
  * Make the connection to LayoutUpdated() work
* Mon Jun  7 2010 dmueller@suse.de
- add baselibs.conf
* Mon May 31 2010 dmueller@suse.de
- correct license (bnc#610291)
* Fri May 28 2010 dmueller@suse.de
- update to 0.3.3:
  * package rename to libdbusmenu-qt
  * Introduce a qt minimum version. Qt 4.5 doesn't work. (Michael Jansen)
  * Use the FindQjson.cmake file made by pinotree for chokoq because it works.
  * Refresh after LayoutUpdated signal (Marco Martin)
  * Test items added to an existing menu are properly imported (Aurelien Gateau)
  * Allow notification of the menu being filled, don't call aboutToShow more than
  once per actual menu showing (Aaron Seigo)
  * Win32 fixes from Ralf Habacker (Patrick Spendrin)
  * Added option to disable tests (Alex Elsayed)
* Wed Apr 28 2010 tittiatcoke@gmail.com
- Initial package
